@@ -711,9 +711,9 @@ delete_cb (GtkWidget  *widget,
 	if (list == NULL)
 		return;
 
-	if (dlg_file_delete (data->window, 
-			     path_list_dup (list),
-			     _("Checked images will be deleted, are you sure ?"))) 
+	if (dlg_file_delete__confirm (data->window, 
+				      path_list_dup (list),
+				      _("Checked images will be deleted, are you sure?"))) 
 		delete_images_from_lists (data, list);
 
 	path_list_free (list);
@@ -1480,6 +1480,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 			break;
 
 		default:
+			break;
 		}
 
 		if (full_uri)
@@ -1501,7 +1502,7 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 
 		path = gnome_vfs_uri_to_string (data->uri, 
 						GNOME_VFS_URI_HIDE_NONE);
-		g_warning ("Cannot load directory \"%s\" : %s\n", path,
+		g_warning ("Cannot load directory \"%s\": %s\n", path,
 			   gnome_vfs_result_to_string (result));
 		g_free (path);
 
