@@ -45,13 +45,16 @@
 #include "typedefs.h"
 
 
-GList       *window_list = NULL;
-FullScreen  *fullscreen;
-char       **file_urls, **dir_urls;
-int          n_file_urls, n_dir_urls;
-int          StartInFullscreen;
-int          StartSlideshow;
-int          ViewFirstImage = FALSE;
+GList               *window_list = NULL;
+FullScreen          *fullscreen;
+char               **file_urls, **dir_urls;
+int                  n_file_urls, n_dir_urls;
+int                  StartInFullscreen;
+int                  StartSlideshow;
+int                  ViewFirstImage = FALSE;
+int                  HideSidebar = FALSE;
+gboolean             ExitAll = FALSE;
+
 
 static gboolean      view_comline_catalog = FALSE;
 static GdkPixbuf    *folder_pixbuf = NULL;
@@ -180,7 +183,7 @@ create_default_categories_if_needed ()
 
 	categories = bookmarks_new (RC_CATEGORIES_FILE);
 	for (i = 0; default_categories[i] != NULL; i++) 
-		bookmarks_add (categories, _(default_categories[i]), TRUE);
+		bookmarks_add (categories, _(default_categories[i]), TRUE, TRUE);
 	bookmarks_write_to_disk (categories);
 	bookmarks_free (categories);
 }
@@ -232,20 +235,32 @@ initialize_data (poptContext pctx)
 
 	current_dir = g_get_current_dir ();
 	for (i = 0; i < argc; i++) {
-		gboolean is_dir;
+		char     *tmp1, *tmp2;
+		gboolean  is_dir;
 
 		if (! g_path_is_absolute (argv[i]))
-			path = g_strconcat (current_dir,
-					    "/",
-					    argv[i],
-					    NULL);
+			tmp1 = g_strconcat (current_dir, "/", argv[i], NULL);
 		else
-			path = g_strdup (argv[i]);
+			tmp1 = g_strdup (argv[i]);
+
+		tmp2= remove_special_dirs_from_path (tmp1);
+
+		if (! g_path_is_absolute (tmp2))
+			path = g_strconcat (current_dir, "/", tmp2, NULL);
+		else {
+			path = tmp2;
+			tmp2 = NULL;
+		}
+		
+		g_free (tmp1);
+		g_free (tmp2);
 
 		if (path_is_dir (path))
 			is_dir = TRUE;
+
 		else if (path_is_file (path))
 			is_dir = FALSE;
+
 		else {
 			g_free (path);
 			continue;
@@ -342,6 +357,7 @@ prepare_app ()
 		g_free (catalog_uri);
 
 		ViewFirstImage = TRUE;
+		HideSidebar = TRUE;
 		current_window = window_new ();
 		gtk_widget_show (current_window->app);
 
@@ -350,7 +366,7 @@ prepare_app ()
 	}
 
 	for (i = 0; i < n_dir_urls; i++) {
-		/* Go to the specified dierectory. */
+		/* Go to the specified directory. */
 		eel_gconf_set_locale_string (PREF_STARTUP_LOCATION, dir_urls[i]);
 
 		current_window = window_new ();
@@ -446,8 +462,19 @@ all_windows_update_browser_options ()
 
 
 void 
-all_windows_update_editors_menu ()
+all_windows_notify_files_created (GList *list)
 {
+	GList *scan;
+
+	for (scan = window_list; scan; scan = scan->next) {
+		GThumbWindow *window = scan->data;
+
+		if ((window->sidebar_content == DIR_LIST) &&
+		    window->monitor_enabled)
+			continue;
+
+		window_notify_files_created (window, list);
+	}
 }
 
 
@@ -469,11 +496,47 @@ all_windows_notify_files_deleted (GList *list)
 
 
 void 
-all_windows_notify_cat_files_deleted (const gchar *catalog_path,
-				      GList *list)
+all_windows_notify_files_changed (GList *list)
 {
 	GList *scan;
 
+	for (scan = window_list; scan; scan = scan->next) {
+		GThumbWindow *window = scan->data;
+
+		if ((window->sidebar_content == DIR_LIST) &&
+		    window->monitor_enabled)
+			continue;
+
+		window_notify_files_changed (window, list);
+	}
+}
+
+
+void 
+all_windows_notify_cat_files_added (const char *catalog_path,
+				    GList      *list)
+{
+	GList *scan;
+
+	if (list == NULL)
+		return;
+
+	for (scan = window_list; scan; scan = scan->next) {
+		GThumbWindow *window = scan->data;
+		window_notify_cat_files_added (window, catalog_path, list);
+	}
+}
+
+
+void 
+all_windows_notify_cat_files_deleted (const char *catalog_path,
+				      GList      *list)
+{
+	GList *scan;
+
+	if (list == NULL)
+		return;
+
 	for (scan = window_list; scan; scan = scan->next) {
 		GThumbWindow *window = scan->data;
 		window_notify_cat_files_deleted (window, catalog_path, list);
